Method: ActiveResource::Base#encode

Defined in:
lib/active_resource/base.rb

#encode(options = {}) ⇒ Object

Returns the serialized string representation of the resource in the configured serialization format specified in ActiveResource::Base.format. The options applicable depend on the configured encoding format.



1429
1430
1431
# File 'lib/active_resource/base.rb', line 1429

def encode(options = {})
  send("to_#{self.class.format.extension}", options)
end