Method: ActiveResource::Base#encode

Defined in:
lib/active_resource/base.rb

#encode(options = {}) ⇒ Object

Returns the serialized string representation of the resource in the configured serialization format specified in ActiveResource::Base.format. The options applicable depend on the configured encoding format.



1214
1215
1216
# File 'lib/active_resource/base.rb', line 1214

def encode(options={})
  send("to_#{self.class.format.extension}", options)
end