Method: ActiveResource::Base#known_attributes
- Defined in:
- lib/active_resource/base.rb
#known_attributes ⇒ Object
This is a list of known attributes for this resource. Either gathered from the provided schema, or from the attributes set on this instance after it has been fetched from the remote system.
1197 1198 1199 |
# File 'lib/active_resource/base.rb', line 1197 def known_attributes (self.class.known_attributes + self.attributes.keys.map(&:to_s)).uniq end |